summaryrefslogtreecommitdiffstats
path: root/chrome/browser/chromeos/frame/bubble_window.h
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/browser/chromeos/frame/bubble_window.h')
-rw-r--r--chrome/browser/chromeos/frame/bubble_window.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/chrome/browser/chromeos/frame/bubble_window.h b/chrome/browser/chromeos/frame/bubble_window.h
index fca4805..a3b313e 100644
--- a/chrome/browser/chromeos/frame/bubble_window.h
+++ b/chrome/browser/chromeos/frame/bubble_window.h
@@ -14,6 +14,7 @@ class Rect;
}
namespace views {
+class Throbber;
class WindowDelegate;
}
@@ -24,7 +25,8 @@ class BubbleWindow : public views::WindowGtk {
public:
enum Style {
STYLE_GENERIC = 0, // Default style.
- STYLE_XBAR = 1 << 0 // Show close button at the top right (left for RTL).
+ STYLE_XBAR = 1 << 0, // Show close button at the top right (left for RTL).
+ STYLE_THROBBER = 1 << 1 // Show throbber for slow rendering.
};
static views::Window* Create(gfx::NativeWindow parent,
@@ -39,8 +41,6 @@ class BubbleWindow : public views::WindowGtk {
// Overidden from views::WindowGtk:
virtual void Init(GtkWindow* parent, const gfx::Rect& bounds);
-
- Style style_;
};
} // namespace chromeos